<?php
/**
 * Configure Legacy Storage engine in Symfony service container
 * Check if object location is not available after trashed
 *
 * @link https://jira.ez.no/browse/EZP-20800
 * @author João Pingo <joao.pingo@ez.no>
 * @date 20/15/2014
 */

namespace MyApp\MyBundle\Command;

use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Input\InputArgument;
use eZ\Publish\API\Repository\Values\Content\Query;

class Ezp20800Command extends ContainerAwareCommand {

    protected function configure() {
        $this
                ->setName('testSystem:ezp20800:CriterionCommand')
                ->setDescription('EZP-20800 - Configure Legacy Storage engine in Symfony service container')
        ;
    }

    /**
     *
     * @return \eZ\Publish\API\Repository\Repository
     */
    protected function getRepo()
    {
        /** @var $repository \eZ\Publish\API\Repository\Repository */
        $repository = $this->getContainer()->get( 'ezpublish.api.repository' );
        return $repository;
    }

    protected function execute(InputInterface $input, OutputInterface $output) {

        $repository = $this->getRepo();
        $userService = $repository->getUserService();
        $searchService = $repository->getSearchService();

        // Login as admin
        $adminUser = $userService->loadUser( 14 );
        $repository->setCurrentUser( $adminUser );

        //Seach for folder with key1
        $query = new Query();

        $criterion1 = new \MyApp\MyBundle\API\Repository\Values\Content\Query\Criterion\TagId( "3" );
        $criterion2 = new \eZ\Publish\API\Repository\Values\Content\Query\Criterion\ContentTypeIdentifier( "article" );
        $query->criterion = $criterion1;

        $search = $searchService->findContent( $query );
        $output->writeln("<fg=green>" . "Results:" . "</fg=green>");
        foreach ( $search->searchHits as $searchHit )
        {
            $output->writeln( $searchHit->valueObject->getVersionInfo()->names );

        }
    }
}
